cal.MyEntriesToday (My appointments today) — amici1

# `cal.MyEntriesToday` (My appointments today)

Columns

- `<django.db.models.fields.BigAutoField: id>`

- `<django.db.models.fields.DateTimeField: modified>`

- `<django.db.models.fields.DateTimeField: created>`

- `<django.db.models.fields.DateField: start_date>`

- `<lino.core.fields.TimeField: start_time>`

- `<django.db.models.fields.DateField: end_date>`

- `<lino.core.fields.TimeField: end_time>`

- `<django.db.models.fields.DateTimeField: build_time>`

- `<lino.core.choicelists.ChoiceListField: build_method>`

- `<django.db.models.fields.related.ForeignKey: user>`

- `<django.db.models.fields.related.ForeignKey: assigned_to>`

- `<django.db.models.fields.related.ForeignKey: owner_type>`

- `<lino.modlib.gfks.fields.GenericForeignKeyIdField: owner_id>`

- `<django.db.models.fields.CharField: summary>`

- `<lino.core.fields.RichTextField: description>`

- `<lino.core.choicelists.ChoiceListField: access_class>`

- `<django.db.models.fields.IntegerField: sequence>`

- `<django.db.models.fields.IntegerField: auto_type>`

- `<lino.core.choicelists.ChoiceListField: priority>`

- `<django.db.models.fields.related.ForeignKey: event_type>`

- `<django.db.models.fields.BooleanField: transparent>`

- `<django.db.models.fields.related.ForeignKey: room>`

- `<lino.core.choicelists.ChoiceListField: state>`

- `<lino.modlib.gfks.fields.GenericForeignKey object at 0x7fc82640c2b0>`

Detail fields

- `<Panel main_1 in lino_xl.lib.cal.ui.EventDetail on lino_xl.lib.cal.ui.Events>`

- `<Panel main_2 in lino_xl.lib.cal.ui.EventDetail on lino_xl.lib.cal.ui.Events>`

- `<Panel main_3 in lino_xl.lib.cal.ui.EventDetail on lino_xl.lib.cal.ui.Events>`

- `<Panel main_4 in lino_xl.lib.cal.ui.EventDetail on lino_xl.lib.cal.ui.Events>`

Actions

- HTML (show_as_html) : Show this table in Bootstrap3 interface

- Table (landscape) (as_pdf) : Show this table as a pdf document.

- Table (portrait) (as_pdf_p) : Show this table as a pdf document.

- Export to .xls (export_excel) : Export this table as an .xls document

- None (grid_post) : See `<lino.core.actions.CreateRow grid_post>`.

- None (grid_put) : See `<lino.core.actions.SaveGridCell grid_put>`.

- New (insert) : Open a dialog window to insert a new Calendar entry.

- Create (submit_insert) : Create the record and open a detail window on it

- ⚇ (duplicate) : Duplicate the selected row.

- Detail (detail) : Open a detail window on this record.

- Delete (delete_selected) : Delete this record

- Print (do_print) : The action used to print this object. This is an instance of DirectPrintAction or CachedPrintAction by default. And if lino_xl.lib.excerpts is installed, then set_excerpts_actions possibly replaces do_print by a lino_xl.lib.excerpts.CreateExcerpt instance.

- Clear cache (do_clear_cache) : Defines the Clear cache button on a Printable record.

- ⚔ (show_conflicting) : A ShowSlaveTable button which opens the ConflictingEvents table for this event.

- Today (show_today) : Show all calendar events of the same day.

- Upload files (show_uploads) : Show uploads in a grid table.

- Assign to me (assign_to_me) : See `<lino.modlib.users.mixins.AssignToMe assign_to_me ('Assign to me')>`.

- Check data (check_data) : See `<lino.modlib.checkdata.models.UpdateProblemsByController check_data ('Check data')>`.

- Create email (create_mail) : Creates an outbox mail and displays it.

- Fix data problems (fix_problems) : See `<lino.modlib.checkdata.models.FixProblemsByController fix_problems ('Fix data problems')>`.

- None (grid) : See `<lino.core.actions.ShowTable grid>`.

- Move down (move_next) : Move this event to next available date

- None (open_help) : See `<lino.core.actions.OpenHelpWindow open_help>`.

- Preview (preview_publication) : See `<lino.modlib.publisher.mixins.PreviewPublication preview_publication ('Preview')>`.

- Take (take) : See `<lino.modlib.users.mixins.TakeAuthorship take ('Take')>`.

- Update Events (update_events) : Create or update all other automatic calendar entries of this series.

- Update presences (update_guests) : Populate or update the list of participants for this calendar entry according to the suggestions.

- None (validate) : See `<lino.core.actions.ValidateForm validate>`.

- Save (submit_detail) : Save changes in this form

- Reset (reset_event) : Suggested

- ☐ (wf2) : Draft

- Took place (wf3) : Took place

- ☒ (wf4) : Cancelled

Filter parameters

- `<django.db.models.fields.DateField: start_date>`

- `<django.db.models.fields.DateField: end_date>`

- `<lino.core.choicelists.ChoiceListField: observed_event>`

- `<lino.core.choicelists.ChoiceListField: show_appointments>`

- `<django.db.models.fields.related.ForeignKey: presence_guest>`

- `<django.db.models.fields.related.ForeignKey: user>`

- `<django.db.models.fields.related.ForeignKey: assigned_to>`

- `<lino.core.fields.DummyField object at 0x7fc81cea64a8>`

- `<lino.core.choicelists.ChoiceListField: state>`

- `<django.db.models.fields.related.ForeignKey: room>`

- `<django.db.models.fields.related.ForeignKey: event_type>`

## Filter parameters